==> fillets-ng-data_0.9.2.orig.tar.gz: fillets-ng-data-0.9.2/script/hole/dialogs_ru.lua <==
dialogId("m-strasidelna", "font_small", "It is a haunted room.")
dialogStr("Это обитаемая комната.")

dialogId("v-bojim", "font_big","I fear it will be dificult to move things over this hole.")
dialogStr("Боюсь, он будет перемащать предметы над этй дырой.")

dialogId("s-prejete", "font_green", "Here you are, as you wish.")
dialogStr("Вы здесь, как пожелали.")

dialogId("l-halo0", "font_lightgrey", "Is anybody there?")
dialogStr("Кто-то там находится?")

dialogId("l-halo1", "font_lightgrey", "Who are there?")
dialogStr("Кто там?")

dialogId("l-halo2", "font_lightgrey", "I think, the receiver does not work.")
dialogStr("Думаю, приемник не работает.")

dialogId("l-dejte0", "font_lightgrey", "Put it back immediately, the indian headdress is mine.")
dialogStr("Положи немедленно его обратно, индийский головной убор - это мина!")

dialogId("l-dejte1", "font_lightgrey", "Put it back immediately, it is mine!")
dialogStr("Положи  немедленно это обратно, это мина!")

dialogId("l-dejte2", "font_lightgrey", "O O O O, I am indian. Put it back immediately!")
dialogStr("Ооооо, я индиец. Положи немедленно это обратно! ")

dialogId("l-dejte3", "font_lightgrey", "O O O O, put it back immediately!")
dialogStr("Ооооо, положи немедленно это обратно!")

dialogId("l-vinnetou", "font_lightgrey", "Where are you pushing me? I am famous Vinnetou!")
dialogStr("Куда ты толкаешь меня? Я знаменитый Vinnetou!")

dialogId("m-nedame0", "font_small", "Sorry, we need it necessarily.")
dialogStr("Извини, нам это очень надо.")

dialogId("v-nedame0", "font_big", "How can it be yours, if you are not indian?")
dialogStr("Как это может быть вашим, если вы не индийцы?")

dialogId("m-nedame1", "font_small", "You can’t be indian because you are not red?")
dialogStr("Вы не можете быть индийцами, потому что вы не красные?")

dialogId("v-nedame1", "font_big", "I can’t demur anything.")
dialogStr("Я не возражаю.")

dialogId("v-neber", "font_big", "Player, if you are an indian, don’t perceive as an discrimination please.")
dialogStr("Игрок, если ты индиец, не воспринимай, пожалуйста, это как дискриминацию.")

dialogId("m-sluchatko", "font_small", "It may be magic receiver.")
dialogStr("Это может быть магический приемник?.")

dialogId("v-zkus", "font_big", "Try it.")
dialogStr("Попробуй.")

dialogId("m-zmizet", "font_small", "Hello, I wish to disappear the steel near exit?")
dialogStr("Привет, я хотел бы исчезнуть около выхода?")

dialogId("v-vratte", "font_big", "Put it back, it should be solved by player, not by ourself.")
dialogStr("Положи обратно, это должен решить игрок, а не мы.")

==> fillets-ng-data_1.0.0.orig.tar.gz: fillets-ng-data-1.0.0/script/hole/dialogs_ru.lua <==
dialogId("m-strasidelna", "font_small", "It is a haunted room.")
dialogStr("Это обитаемая комната.")

dialogId("v-bojim", "font_big", "I fear it will be dificult to move things over this hole.")
dialogStr("Боюсь, он будет перемащать предметы над этй дырой.")

dialogId("s-prejete", "font_green", "Here you are, as you wish.")
dialogStr("Вы здесь, как пожелали.")

dialogId("l-halo0", "font_lightgrey", "Is anybody there?")
dialogStr("Кто-то там находится?")

dialogId("l-halo1", "font_lightgrey", "Who is there?")
dialogStr("Кто там?")

dialogId("l-halo2", "font_lightgrey", "I think, the receiver does not work.")
dialogStr("Думаю, приемник не работает.")

dialogId("l-dejte0", "font_lightgrey", "Put it back immediately, the indian headdress is mine.")
dialogStr("Положи немедленно его обратно, индийский головной убор - это мина!")

dialogId("l-dejte1", "font_lightgrey", "Put it back immediately, it is mine!")
dialogStr("Положи  немедленно это обратно, это мина!")

dialogId("l-dejte2", "font_lightgrey", "O O O O, I am indian. Put it back immediately!")
dialogStr("Ооооо, я индиец. Положи немедленно это обратно! ")

dialogId("l-dejte3", "font_lightgrey", "O O O O, put it back immediately!")
dialogStr("Ооооо, положи немедленно это обратно!")

dialogId("l-vinnetou", "font_lightgrey", "Where are you pushing me? I am famous Vinnetou!")
dialogStr("Куда ты толкаешь меня? Я знаменитый Vinnetou!")

dialogId("m-nedame0", "font_small", "Sorry, we need it necessarily.")
dialogStr("Извини, нам это очень надо.")

dialogId("v-nedame0", "font_big", "How can it be yours, if you are not indian?")
dialogStr("Как это может быть вашим, если вы не индийцы?")

dialogId("m-nedame1", "font_small", "You can’t be an indian because you are not red.")
dialogStr("Вы не можете быть индийцами, потому что вы не красные?")

dialogId("v-nedame1", "font_big", "I can’t demur anything.")
dialogStr("Я не возражаю.")

dialogId("v-neber", "font_big", "Player, if you are an indian, don’t perceive it as an discrimination please.")
dialogStr("Игрок, если ты индиец, не воспринимай, пожалуйста, это как дискриминацию.")

dialogId("m-sluchatko", "font_small", "It may be a magic receiver.")
dialogStr("Это может быть магический приемник?.")

dialogId("v-zkus", "font_big", "Try it.")
dialogStr("Попробуй.")

dialogId("m-zmizet", "font_small", "Hello, I wish to disappear the steel near exit?")
dialogStr("Привет, я хотел бы исчезнуть около выхода?")

dialogId("v-vratte", "font_big", "Put it back, it should be solved by player, not by ourself.")
dialogStr("Положи обратно, это должен решить игрок, а не мы.")
